Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
committerJacques Lucke <jacques@blender.org>2020-06-09 11:27:24 +0300
commit9bb7d6ed68ef1aa0e6acc3e70901cb6b79c682d2 (patch)
tree843993222b8ee5c02451207404ceb113323ede6f /source/blender/blenlib/BLI_hash.hh
parentd8678e02ecec9375bec1dcf1388c6fc8b4ce3ad2 (diff)
BLI: put C++ data structures in "blender" namespace instead of "BLI"
We plan to use the "blender" namespace in other modules as well.
Diffstat (limited to 'source/blender/blenlib/BLI_hash.hh')
-rw-r--r--source/blender/blenlib/BLI_hash.hh14
1 files changed, 7 insertions, 7 deletions
diff --git a/source/blender/blenlib/BLI_hash.hh b/source/blender/blenlib/BLI_hash.hh
index 029fa32553a..57d5f7f9d8a 100644
--- a/source/blender/blenlib/BLI_hash.hh
+++ b/source/blender/blenlib/BLI_hash.hh
@@ -20,8 +20,8 @@
/** \file
* \ingroup bli
*
* A specialization of `BLI::DefaultHash<T>` provides a hash function for values of type T. This
* hash function is used by default in hash table implementations in blenlib.
*
* The actual hash function is in the `operator()` method of DefaultHash<T>. The following code
* computes the hash of some value using DefaultHash.
@@ -30,8 +30,8 @@
* DefaultHash<T> hash_function;
* uint32_t hash = hash_function(value);
*
* Hash table implementations like BLI::Set support heterogeneous key lookups. That means that one
* can do a lookup with a key of type A in a hash table that stores keys of type B. This is
* commonly done when B is std::string, because the conversion from e.g. a StringRef to std::string
* can be costly and is unnecessary. To make this work, values of type A and B that compare equal
* have to have the same hash value. This is achieved by defining potentially multiple `operator()`
@@ -57,7 +57,7 @@
* specialization to the DefaultHash struct. This can be done by writing code like below in
* either global or BLI namespace.
*
- * template<> struct BLI::DefaultHash<TheType> {
+ * template<> struct blender::DefaultHash<TheType> {
* uint32_t operator()(const TheType &value) const {
* return ...;
* }
@@ -83,7 +83,7 @@
#include "BLI_string_ref.hh"
#include "BLI_utildefines.h"
-namespace BLI {
+namespace blender {
/**
* If there is no other specialization of DefaultHash for a given type, try to call `hash()` on the
@@ -206,6 +206,6 @@ template<typename T1, typename T2> struct DefaultHash<std::pair<T1, T2>> {
}
};
-} // namespace BLI
+} // namespace blender
#endif /* __BLI_HASH_HH__ */
@@ -20,8 +20,8 @@
* \ingroup bli
*
- * A specialization of `BLI::DefaultHash<T>` provides a hash function for values of type T. This
- * hash function is used by default in hash table implementations in blenlib.
+ * A specialization of `blender::DefaultHash<T>` provides a hash function for values of type T.
+ * This hash function is used by default in hash table implementations in blenlib.
*
* The actual hash function is in the `operator()` method of DefaultHash<T>. The following code
@@ -30,8 +30,8 @@
* uint32_t hash = hash_function(value);
*
- * Hash table implementations like BLI::Set support heterogeneous key lookups. That means that one
- * can do a lookup with a key of type A in a hash table that stores keys of type B. This is
+ * Hash table implementations like blender::Set support heterogeneous key lookups. That means that
+ * one can do a lookup with a key of type A in a hash table that stores keys of type B. This is
* commonly done when B is std::string, because the conversion from e.g. a StringRef to std::string
* can be costly and is unnecessary. To make this work, values of type A and B that compare equal